Rdocumentation
powered by
Learn R Programming
electionsBR (version 0.3.1)
parties_br: Returns a vector with the abbreviations of all Brazilian parties
Description
The character vector includes only parties that ran in elections in 2016.
Usage
parties_br()
Arguments