- year
Election year. For this function, only the years 2006, 2010, 2014 and 2018 are available.
- uf
Federation Unit acronym (character vector).
- br_archive
In the TSE's data repository, some results can be obtained for the whole country by loading a single
within a single file by setting this argument to TRUE (may not work in for some elections and, in
other, it recoverns only electoral data for presidential elections, absent in other files).
- encoding
Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors
when ascii = TRUE.
- temp
(logical). If TRUE, keep the temporary compressed file for future use (recommended)