seats_local: Download data on the number of seats under dispute in local elections
Description
seats_local() downloads and aggregates data on the number of seats under dispute in
local elections in Brazil. The function returns a tbl, data.frame where each observation
corresponds to a municipality office dyad.
Usage
seats_local(year, uf = "all", encoding = "latin1", temp = TRUE)
Value
seats_local() returns a data.frame.
Arguments
- year
Election year. For this function, onlye the years of 1996, 2000, 2004, 2008, 2012, 2016 and 2020
are available.
- uf
Federation Unit acronym (character vector).
- encoding
Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors
when ascii = TRUE.
- temp
(logical). If TRUE, keep the temporary compressed file for future use (recommended)
Details
If export is set to TRUE, the downloaded data is saved as .dta and .sav
files in the current directory.
Examples
Run this codeif (FALSE) {
df <- seats_local(2000)
}
Run the code above in your browser using DataLab