Rdocumentation
powered by
Learn R Programming
electionsBR (version 0.3.1)
uf_br: Returns a vector with the abbreviations of all Brazilian states
Description
Returns a vector with the abbreviations of all Brazilian states
Usage
uf_br()
Arguments