Learn R Programming

electionsBR (version 0.3.1)

vote_section_fed: Download data on candidate electoral results in federal elections in Brazil by electoral section

Description

vote_section_fed() downloads and cleans data on the verification of federal elections in Brazil, disaggregated by electoral section. Different from other electionsBR's functions, results are only extract for individual states, one at a time. The function returns a data.frame where each observation corresponds to an electoral section in a given Brazilian state.

Usage

vote_section_fed(year, uf = "AC", ascii = FALSE, encoding = "latin1",
  export = FALSE)

Arguments

year

Election year. For this function, only the years 1998, 2002, 2006, 2010, and 2014 are available.

uf

Federation Unit acronym (character vector). Defaults to 'AC' (Acre).

ascii

(logical). Should the text be transformed from Latin-1 to ASCII format?

encoding

Data original encoding (defaults to 'Latin-1'). This can be changed to avoid errors when ascii = TRUE.

export

(logical). Should the downloaded data be saved in .dta and .sav in the current directory?

Value

vote_section_fed() returns a data.frame with the following variables:

  • DATA_GERACAO: Generation date of the file (when the data was collected).

  • HORA_GERACAO: Generation time of the file (when the data was collected), Brasilia Time.

  • ANO_ELEICAO: Election year.

  • NUM_TURNO: Round number.

  • DESCRICAO_ELEICAO: Description of the election.

  • SIGLA_UF: Units of the Federation's acronym in which occurred the election.

  • SIGLA_UE: Units of the Federation's acronym (In case of major election is the FU's acronym in which the candidate runs for (text) and in case of municipal election is the municipal's Supreme Electoral Court code (number)). Assume the special values BR, ZZ and VT to designate, respectively, Brazil, Overseas and Absentee Ballot.

  • CODIGO_MUNICIPIO: Supreme Electoral code from the city where occurred the election.

  • NOME_MUNICIPIO: Name of the city where occurred the election.

  • NUMERO_ZONA: Zone number.

  • NUMERO_SECAO: Electoral section number.

  • CODIGO_CARGO: Code of the position that the candidate runs for.

  • DESCRICAO_CARGO: Description of the position that the candidate runs for.

  • NUM_VOTAVEL: Candidate's number in the ballot box.

  • QTDE_VOTOS: Number of votes.

Details

If export is set to TRUE, the data is saved as .dta and .sav files in the working directory.

See Also

vote_section_local for local elections in Brazil.

Examples

Run this code
# NOT RUN {
df <- vote_section_fed(2002)
# }

Run the code above in your browser using DataLab